@@ -19,7 +19,6 @@ class Stax:
         self.sess = retry()
 
 
-
     def getDocument(self, presigned:bool=True, document:str=None):
         '''
         Get document metadata.
@@ -51,7 +50,7 @@ class Stax:
             return res
         
         with open(path, 'wb') as f:
-            f.write(res)
+            f.write(res.content)
 
 
     def downloadPage(self, key:str=None, document:str=None, path:str=None):
@@ -70,7 +69,7 @@ class Stax:
             return res
         
         with open(path, 'wb') as f:
-            f.write(res)
+            f.write(res.content)
 
     
     def updateDocument(self, diff={}, document:str=None):
@@ -84,7 +83,7 @@ class Stax:
         self.post('/document/update', {
             "docId": document_id,
             "docDiff": diff
-        })
+        }, raw=True)
 
 
     def downloadConfigFile(self, config:'list[dict]'=[], label:str=None, path:str=None):
@@ -122,7 +121,11 @@ class Stax:
     def _handle_response_(self, res):
         if res.status_code != 200:
             raise Exception("Failed to communicate with Stax.ai API")
-        data = res.json()
-        if not data['success']:
-            raise Exception("API Error:" + json.dumps(res))
-        return data
+        try:
+            data = res.json()
+            if not data['success']:
+                raise Exception("API Error:" + json.dumps(data))
+
+            return data
+        except Exception as e:
+            raise Exception("API Parse Error:" + str(e) + "\n" + res.content)
