@@ -9,6 +9,13 @@ def getConfigByLabel(config:'list[dict]', label:str):
     return None
 
 
+def getValueByKey(fields:'list[dict]', key:str) -> (str):
+    for f in fields:
+        if "key" in f and "value" in f and f["key"] == key:
+            return f["value"]
+    return ""
+
+
 def getFieldByKey(fields:'list[dict]', key:str):
     for f in fields:
         if "key" not in f or "value" not in f:
